@@ -29,8 +29,8 @@ class MunicipioAdmin(admin.ModelAdmin):
     fieldsets = (
         (None, {
             'fields': ('codigo_ibge', 'codigo_mesorregiao',
-                       'codigo_microrregiao', 'nome', 'uf', 'is_capital',
-                       'populacao', 'is_polo')
+                       'codigo_microrregiao', 'nome', 'uf', 'slug',
+                       'is_capital', 'populacao', 'is_polo')
         }),
         ('Posição geográfica', {
             'fields': ('latitude', 'longitude'),
@@ -38,6 +38,7 @@ class MunicipioAdmin(admin.ModelAdmin):
     )
     search_fields = ('codigo_ibge', 'codigo_mesorregiao',
                      'codigo_microrregiao', 'nome', 'uf__nome', 'uf__sigla')
+    prepopulated_fields = {"slug": ('nome', 'uf',)}
 
 
 admin.site.register(ibge.models.UnidadeFederativa, UnidadeFederativaAdmin)
